@@ -1,5 +1,5 @@
 package Mojolicious::Command::jobcontrol;
-$Mojolicious::Command::jobcontrol::VERSION = '0.7.0';
+$Mojolicious::Command::jobcontrol::VERSION = '0.18.0';
 use Mojo::Base 'Mojolicious::Command';
 
 use Data::Dumper;
@@ -20,8 +20,11 @@ sub run {
     print "\n";
     print "Commands:\n";
     print "\n";
+    print "version       print the version.\n";
+    print "\n";
     print "setup         create all required folders\n";
-    print "systemd -c    create systemd unit files for JobControl and Minion.\n";
+    print
+      "systemd -c    create systemd unit files for JobControl and Minion.\n";
     print "upstart -c    create upstart files for JobControl and Minion.\n";
     print "\n";
     print "User Management:\n";
@@ -32,30 +35,35 @@ sub run {
     exit 0;
   }
 
-  if($command eq "systemd") {
-    my ($create_unit, $start, $stop, $restart) = @_;
+  if ( $command eq "version" ) {
+    print "This is Rex::JobControl (" . $Rex::JobControl::VERSION . ")\n";
+    exit 0;
+  }
+
+  if ( $command eq "systemd" ) {
+    my ( $create_unit, $start, $stop, $restart ) = @_;
 
     GetOptionsFromArray \@args,
-      'c|create-unit'     => sub { $create_unit = 1 },
-      's|start' => sub { $start = 1 },
-      'r|restart' => sub { $restart = 1 },
-      'k|stop' => sub { $stop = 1 };
+      'c|create-unit' => sub { $create_unit = 1 },
+      's|start'       => sub { $start       = 1 },
+      'r|restart'     => sub { $restart     = 1 },
+      'k|stop'        => sub { $stop        = 1 };
 
-    if($create_unit) {
+    if ($create_unit) {
       $self->create_systemd_unit();
     }
   }
 
-  if($command eq "upstart") {
-    my ($create_unit, $start, $stop, $restart) = @_;
+  if ( $command eq "upstart" ) {
+    my ( $create_unit, $start, $stop, $restart ) = @_;
 
     GetOptionsFromArray \@args,
-      'c|create-unit'     => sub { $create_unit = 1 },
-      's|start' => sub { $start = 1 },
-      'r|restart' => sub { $restart = 1 },
-      'k|stop' => sub { $stop = 1 };
+      'c|create-unit' => sub { $create_unit = 1 },
+      's|start'       => sub { $start       = 1 },
+      'r|restart'     => sub { $restart     = 1 },
+      'k|stop'        => sub { $stop        = 1 };
 
-    if($create_unit) {
+    if ($create_unit) {
       $self->create_upstart_unit();
     }
   }
@@ -63,31 +71,63 @@ sub run {
   if ( $command eq "setup" ) {
     my $changed = 0;
 
-    if(! -d $self->app->config->{project_path} ) {
-      $self->app->log->info("Creating project path: " . $self->app->config->{project_path});
-      File::Path::make_path($self->app->config->{project_path});
+    if ( !-d $self->app->config->{project_path} ) {
+      $self->app->log->info(
+        "Creating project path: " . $self->app->config->{project_path} );
+      File::Path::make_path( $self->app->config->{project_path} );
       $changed = 1;
     }
 
-    if(! -d dirname($self->app->config->{minion_db_file}) ) {
-      $self->app->log->info("Creating minion db path: " . dirname($self->app->config->{minion_db_file}));
-      File::Path::make_path(dirname($self->app->config->{minion_db_file}));
+    if ( !-d dirname( $self->app->config->{minion_db_file} ) ) {
+      $self->app->log->info( "Creating minion db path: "
+          . dirname( $self->app->config->{minion_db_file} ) );
+      File::Path::make_path( dirname( $self->app->config->{minion_db_file} ) );
       $changed = 1;
     }
 
-    if(! -d dirname($self->app->config->{auth}->{passwd}) ) {
-      $self->app->log->info("Creating passwd path: " . dirname($self->app->config->{auth}->{passwd}));
-      File::Path::make_path(dirname($self->app->config->{auth}->{passwd}));
+    if ( !-d $self->app->config->{upload_tmp_path} ) {
+      $self->app->log->info(
+        "Creating upload_tmp_path: " . $self->app->config->{upload_tmp_path} );
+      File::Path::make_path( $self->app->config->{upload_tmp_path} );
       $changed = 1;
     }
 
-    if(! -f $self->app->config->{auth}->{passwd}) {
-      $self->app->log->info("No passwd file found. Creating one with user 'admin' and password 'admin'.");
-      $self->add_user("admin", "admin");
+    if ( !-d dirname( $self->app->config->{auth}->{passwd} ) ) {
+      $self->app->log->info( "Creating passwd path: "
+          . dirname( $self->app->config->{auth}->{passwd} ) );
+      File::Path::make_path( dirname( $self->app->config->{auth}->{passwd} ) );
       $changed = 1;
     }
 
-    if($changed == 0) {
+    if ( exists $self->app->config->{log}->{audit_log}
+      && !-d dirname( $self->app->config->{log}->{audit_log} ) )
+    {
+      $self->app->log->info( "Creating audit.log path: "
+          . dirname( $self->app->config->{log}->{audit_log} ) );
+      File::Path::make_path(
+        dirname( $self->app->config->{log}->{audit_log} ) );
+      $changed = 1;
+    }
+
+    if ( exists $self->app->config->{log}->{access_log}
+      && !-d dirname( $self->app->config->{log}->{access_log} ) )
+    {
+      $self->app->log->info( "Creating access.log path: "
+          . dirname( $self->app->config->{log}->{access_log} ) );
+      File::Path::make_path(
+        dirname( $self->app->config->{log}->{access_log} ) );
+      $changed = 1;
+    }
+
+    if ( !-f $self->app->config->{auth}->{passwd} ) {
+      $self->app->log->info(
+        "No passwd file found. Creating one with user 'admin' and password 'admin'."
+      );
+      $self->add_user( "admin", "admin" );
+      $changed = 1;
+    }
+
+    if ( $changed == 0 ) {
       $self->app->log->info("Everything seems ok.");
     }
 
@@ -100,7 +140,7 @@ sub run {
       'u|user=s'     => sub { $user     = $_[1] },
       'p|password=s' => sub { $password = $_[1] };
 
-    $self->add_user($user, $password);
+    $self->add_user( $user, $password );
   }
 
   if ( $command eq "deluser" ) {
@@ -132,7 +172,7 @@ sub run {
 }
 
 sub add_user {
-  my ($self, $user, $password) = @_;
+  my ( $self, $user, $password ) = @_;
 
   $self->app->log->debug("Creating new user $user with password $password");
 
@@ -160,7 +200,7 @@ sub create_upstart_unit {
   my $whereis_hypnotoad = qx{which hypnotoad};
   chomp $whereis_hypnotoad;
 
-  open(my $fh, ">", "/etc/init/rex-jobcontrol.conf") or die ($!);
+  open( my $fh, ">", "/etc/init/rex-jobcontrol.conf" ) or die($!);
   print $fh qq~# Rex::JobControl
 
 description     "Rex::JobControl upstart job"
@@ -173,7 +213,7 @@ post-stop exec $whereis_hypnotoad $0 -s
 ~;
   close($fh);
 
-  open($fh, ">", "/etc/init/rex-jobcontrol-minion.conf") or die ($!);
+  open( $fh, ">", "/etc/init/rex-jobcontrol-minion.conf" ) or die($!);
   print $fh qq~# Rex::JobControl Minion
 
 description     "Rex::JobControl Minion upstart job"
@@ -181,7 +221,7 @@ description     "Rex::JobControl Minion upstart job"
 start on runlevel [2345]
 stop on runlevel [!2345]
 
-exec /usr/local/bin/rex_job_control minion worker
+exec $0 minion worker
 ~;
   close($fh);
 
@@ -195,7 +235,7 @@ sub create_systemd_unit {
   my $whereis_hypnotoad = qx{which hypnotoad};
   chomp $whereis_hypnotoad;
 
-  open(my $fh, ">", "/lib/systemd/system/rex-jobcontrol.service") or die ($!);
+  open( my $fh, ">", "/lib/systemd/system/rex-jobcontrol.service" ) or die($!);
   print $fh qq~[Unit]
 Description=Rex JobControl Server
 After=network.target
@@ -210,7 +250,8 @@ ExecReload=$whereis_hypnotoad $0
 ~;
   close($fh);
 
-  open(my $fh_m, ">", "/lib/systemd/system/rex-jobcontrol-minion.service") or die ($!);
+  open( my $fh_m, ">", "/lib/systemd/system/rex-jobcontrol-minion.service" )
+    or die($!);
   print $fh_m qq~[Unit]
 Description=Rex JobControl Minion
 After=network.target
